
# Geomancy

```{include} ../README.md
:start-after: <!-- start badges -->
:end-before: <!-- end badges -->
```
```{include} ../README.md
:start-after: <!-- start intro -->
:end-before: <!-- end intro -->
```

## Features

```{include} ../README.md
:start-after: <!-- start features -->
:end-before: <!-- end features -->
```

```{toctree}
:hidden:

quickstart
```
```{toctree}
:hidden:
:caption: Usage
:maxdepth: 1

usage/cmd_checks
usage/cmd_run
usage/format
```

```{toctree}
:hidden:
:caption: Checks
:maxdepth: 1

checks/core
checks/aws
```

```{toctree}
:hidden:
:caption: Guides
:maxdepth: 1

guides/tips_and_tricks
```

```{toctree}
:hidden:
:caption: About the Project
:maxdepth: 1

about/changelog
about/api/index
```
